@@ -1,9 +1,11 @@
 package Pcore::App::Sphinx;
 
-use Pcore qw[-cli -class];
+use Pcore qw[-class];
 
 extends qw[Pcore::App::Alien];
 
+with qw[Pcore::Core::CLI::Opt::Perms];
+
 has '+name' => ( default => 'sphinx' );
 has '+ns'   => ( default => 'Pcore::Sphinx' );
 
@@ -18,18 +20,34 @@ our $CFG = {
     }
 };
 
-sub _build_sphinx_ver {
-    my $self = shift;
+# CLI
+sub cli_name ($self) {
+    return 'sphinx';
+}
 
-    return $self->cfg->{SPHINX}->{SPHINX_VER} || $DIST->{SPHINX}->{SPHINX_VER};
+around cli_opt => sub ( $orig, $self ) {
+    my $opt = $self->$orig;
+
+    $opt->{r2_system} = {
+        short => undef,
+        desc  => q[install re2 to /usr/local instead of sphinx app. directory],
+    };
+
+    $opt->{indexer} = {
+        short => undef,
+        desc  => q[],
+    };
+
+    return $opt;
+};
+
+sub _build_sphinx_ver ($self) {
+    return $self->cfg->{SPHINX}->{SPHINX_VER} || $PROC->{CFG}->{SPHINX}->{SPHINX_VER};
 }
 
 # APP
-around run => sub {
-    my $orig = shift;
-    my $self = shift;
-
-    if ( $ARGV{indexer} ) {
+around run => sub ( $orig, $self ) {
+    if ( $ARGV{opt}->{indexer} ) {
         say q[start indexer];
 
         $self->generate_alien_cfg;
@@ -44,10 +62,7 @@ around run => sub {
     return;
 };
 
-around _build_cfg => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around _build_cfg => sub ( $orig, $self ) {
     return P->hash->merge(
         $self->$orig,
         $CFG,
@@ -123,10 +138,7 @@ around _build_cfg => sub {
     );
 };
 
-around _create_local_cfg => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around _create_local_cfg => sub ( $orig, $self ) {
     my $local_cfg = {
         SPHINX => {
             SPHINX_VER => $self->cfg->{SPHINX}->{SPHINX_VER},
@@ -137,15 +149,11 @@ around _create_local_cfg => sub {
     return P->hash->merge( $self->$orig, $local_cfg );
 };
 
-sub _build_alien_dir {
-    my $self = shift;
-
+sub _build_alien_dir ($self) {
     return $self->app_dir . 'sphinx-' . $self->sphinx_ver . q[/];
 }
 
-sub _build_alien_data_dir {
-    my $self = shift;
-
+sub _build_alien_data_dir ($self) {
     my $dir = $self->app_dir . 'sphinx-data/';
 
     P->file->mkpath($dir);
@@ -153,9 +161,7 @@ sub _build_alien_data_dir {
     return $dir;
 }
 
-sub _build_alien_cfg_dir {
-    my $self = shift;
-
+sub _build_alien_cfg_dir ($self) {
     my $dir = $self->app_dir . 'indexes';
 
     P->file->mkpath($dir);
@@ -163,28 +169,19 @@ sub _build_alien_cfg_dir {
     return $dir;
 }
 
-sub _build_alien_bin_path {
-    my $self = shift;
-
+sub _build_alien_bin_path ($self) {
     return $self->alien_dir . 'bin/searchd';
 }
 
-sub _build_alien_indexer_bin_path {
-    my $self = shift;
-
+sub _build_alien_indexer_bin_path ($self) {
     return $self->alien_dir . 'bin/indexer';
 }
 
-sub _build_alien_cfg_path {
-    my $self = shift;
-
+sub _build_alien_cfg_path ($self) {
     return $self->app_dir . 'sphinx.conf';
 }
 
-around app_build => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around app_build => sub ( $orig, $self ) {
     $self->$orig;
 
     if ( -d $self->alien_dir ) {
@@ -194,7 +191,7 @@ around app_build => sub {
         my $res = try {
 
             # re2
-            my $re2_prefix = ( $ARGV{r2_system} ? q[/usr/local/] : $self->alien_dir ) . 're2/';
+            my $re2_prefix = ( $ARGV{opt}->{r2_system} ? q[/usr/local/] : $self->alien_dir ) . 're2/';
             P->file->rmtree($re2_prefix);
             P->file->mkpath($re2_prefix);
 
@@ -244,18 +241,13 @@ around app_build => sub {
     return;
 };
 
-around app_deploy => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around app_deploy => sub ( $orig, $self ) {
     $self->$orig;
 
     return;
 };
 
-sub generate_alien_cfg {
-    my $self = shift;
-
+sub generate_alien_cfg ($self) {
     my %cfg;
 
     for my $section ( sort keys %{ $self->cfg->{SPHINX}->{SERVER} } ) {
@@ -287,15 +279,11 @@ sub generate_alien_cfg {
     return;
 }
 
-sub master_proc {
-    my $self = shift;
-
+sub master_proc ($self) {
     return;
 }
 
-sub alien_proc {
-    my $self = shift;
-
+sub alien_proc ($self) {
     $self->generate_alien_cfg;
 
     exec $self->alien_bin_path, q[--config], $self->alien_cfg_path, q[--nodetach] or die;
@@ -307,16 +295,4 @@ __END__
 
 =encoding utf8
 
-=head1 OPTIONS
-
-=over
-
-=item --indexer
-
-=item --r2-system
-
-Install re2 to /usr/local instead of sphinx directory
-
-=back
-
 =cut
