@@ -20,7 +20,7 @@ sub _build__connection {
         }
     );
 
-    return [ q[DBI:mysql:database=;host=] . P->uri( $self->addr )->host_port, $self->username, $self->password, $attr ];
+    return [ q[DBI:mysql:database=;host=] . P->uri( $self->addr )->hostport, $self->username, $self->password, $attr ];
 }
 
 1;
